/**
 * This is a template for new plugin wrappers
 *
 * TODO:
 * - Add/Change information below
 * - Document usage (importing, executing main functionality)
 * - Remove any imports that you are not using
 * - Remove all the comments included in this template, EXCEPT the @Plugin wrapper docs and any other docs you added
 * - Remove this note
 *
 */
import { Injectable } from '@angular/core';
import { Plugin, Cordova, AwesomeCordovaNativePlugin } from '@awesome-cordova-plugins/core';

/**
 * @name Shuto SangforVpnPlugin
 * @description
 * This plugin does something
 *
 * @usage
 * ```typescript
 * import { ShutoZip } from '@shuto-cordova-plugins/zip';
 *import { SFSmsMessage } from 'src/@awesome-cordova-plugins/shuto/sangforvpn/index';

 *
 * constructor(private shutoZip: ShutoZip) { }
 *
 * ...
 *
 *
 * this.shutoZip.functionName('Hello', 123)
 *   .then((res: any) => console.log(res))
 *   .catch((error: any) => console.error(error));
 *
 * ```
 */
@Plugin({
  pluginName: 'SangforVpnPlugin',
  plugin: 'cordova-plugin-sangforvpn',
  pluginRef: 'SangforVpnPlugin',
  repo: 'https://m.shuto.cn:8681/public/cordova-plugin-sangforvpn.git',
  platforms: ['Android', 'iOS'],
})
@Injectable()
export class SangforVpnPlugin extends AwesomeCordovaNativePlugin {
  SFLogoutType: SFLogoutType;
  SFAuthType: SFAuthType;
  /**
   * 用户名密码认证
   * @param {string} username
   * @param {string} password
   */
  @Cordova()
  startPasswordAuth(username: string, password: string) {
    // no code;
  }

  onAuthSuccess(callback: (message: SFBaseMessage) => {}) {
    window.addEventListener('sangforvpn.onAuthSuccess', callback as any);
  }
  onAuthFailed(callback: (message: SFBaseMessage) => {}) {
    window.addEventListener('sangforvpn.onAuthFailed', callback as any);
  }
  onAuthProgress(callback: (message: SFBaseMessage & { sfAuthType: number }) => {}) {
    window.addEventListener('sangforvpn.onAuthProgress', callback as any);
  }
  onLogout(callback: (message: SFBaseMessage & { sfLogoutType: number }) => {}) {
    window.addEventListener('sangforvpn.onLogout', callback as any);
  }
  @Cordova()
  async startAutoTicket(): Promise<{ success: boolean }> {
    return { success: false };
  }

  @Cordova()
  async reGetSmsCode(): Promise<SFSmsMessage> {
    return {} as any as SFSmsMessage;
  }
  @Cordova()
  async reGetRandCode(): Promise<string> {
    return '';
  }
  @Cordova()
  async doSecondAuth(type: number, code: string) {
    // no code;
  }
}

export interface SFBaseMessage {
  mErrCode: number;
  mErrStr: string;
  mServerInfo: string;
  currentAuthType: number;
}
export interface SFSmsMessage extends SFBaseMessage {
  phoneNum: string;
  countDown: number;
  smsApps: string;
  stillValid: boolean;
}

export class SFLogoutType {
  LOGOUT_TYPE_USER_ACTIVE = 0;
  LOGOUT_TYPE_TCIKET_AUTH_ERROR = 1;
  LOGOUT_TYPE_SERVER_SHUTDOWN = 2;
  LOGOUT_TYPE_AUTHOR_ERROR = 3;
  LOGOUT_TYPE_OTHERS = 100;
}

export class SFAuthType {
  AUTH_TYPE_UNKNOWN = -1;
  AUTH_TYPE_CERTIFICATE = 0;
  AUTH_TYPE_PASSWORD = 1;
  AUTH_TYPE_SMS = 2;
  AUTH_TYPE_SMS2 = 3;
  AUTH_TYPE_HARDID = 4;
  AUTH_TYPE_SESSION = 16;
  AUTH_TYPE_NONE = 17;
  AUTH_TYPE_RENEW_PASSWORD = 18;
  AUTH_TYPE_RAND = 22;
  AUTH_TYPE_SANGFORID = 23;
  AUTH_TYPE_QYWECHAT = 24;
  AUTH_TYPE_TOKEN_TOTP = 25;
  AUTH_TYPE_TOKEN_RADIUS = 26;
  AUTH_TYPE_TOKEN_HTTPS = 27;
  AUTH_TYPE_AUTH_CHECK = 28;
  AUTH_TYPE_PURE_BIND_AUTH_DEVICE = 29;
  AUTH_TYPE_APPLY_BIND_AUTH_DEVICE = 30;
  AUTH_TYPE_UNBIND_AUTH_DEVICE = 31;
  AUTH_TYPE_PURE_TRUST_DEVICE = 32;
  AUTH_TYPE_APPLY_TRUST_DEVICE = 33;
  AUTH_TYPE_UNBIND_TRUST_DEVICE = 34;
  AUTH_TYPE_PRE_ENHANCED = 35;
  AUTH_TYPE_FORGET_PWD_PRE = 36;
  AUTH_TYPE_FORGET_PWD = 37;
  AUTH_TYPE_RESET_PWD = 38;
  AUTH_TYPE_CAS = 39;
  AUTH_TYPE_CAS_PRE = 40;
  AUTH_TYPE_PRIMARY_SMS_PRE = 41;
  AUTH_TYPE_PRIMARY_SMS = 42;
  AUTH_TYPE_THIRD_CODE = 43;
  AUTH_TYPE_TICKET = 2048;
  AUTH_TYPE_DINGDING_CODE = 11;
  AUTH_TYPE_AUTHOR = 10;
  AUTH_TYPE_TOKEN = 7;
  AUTH_TYPE_RADIUS = 6;
}
